@@ -22,9 +22,9 @@ except:
 def run():
     print('Opening Bokeh application on http://localhost:5006/')
     # sourceqt.qt_button()
-    server = Server({'/': source.main},
-                    allow_websocket_origin=["localhost:5006"], port=5006, show=False, num_procs=1) 
-    server.start()  
+    server = Server({'/': source.main}, port=5006)
+                   # allow_websocket_origin=["localhost:5006"], port=5006, show=False, num_procs=1) 
+    # server.start()  
     
     server.io_loop.start()
 
